package com.ydl.auth.apis;


import com.alibaba.dubbo.config.annotation.Reference;
import com.google.common.collect.Maps;
import com.ydl.auth.dto.AccessRequestDto;
import com.ydl.auth.dto.RequestDTO;
import com.ydl.auth.inf.AppAuthFacade;
import com.ydl.auth.inf.ComOssFacade;
import com.ydl.common.dto.BaseDtoResponse;
import com.ydl.common.helper.ResponseFormatterHelper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.util.DigestUtils;
import org.springframework.web.bind.annotation.*;

import java.util.*;
import java.util.stream.Collectors;

@RestController
@RequestMapping(value = "/sign")
@Api(description = "获取签名")
public class SignController {


	@Reference(version = "1.0.0")
	private AppAuthFacade appAuthFacade;

	@Reference(version = "1.0.0")
	private ComOssFacade comOssFacade;

	@RequestMapping(value = "/getAccessKey", method = RequestMethod.POST)
	@ApiOperation(value = "获取验签")
	public BaseDtoResponse<String> getAccessKey(@RequestBody AccessRequestDto requestDto) throws Exception {

		String appSecret = appAuthFacade.getSecretByAppKey(requestDto.getAppKey());
		Long timeStamp = System.currentTimeMillis();
		String version = "1.0.0";
		Map<String,String> paramMap = new HashMap<>();
		paramMap.put("timestamp",timeStamp+"");
		paramMap.put("path",requestDto.getPath());
		paramMap.put("version",version);
		String sign = generateSign(appSecret,paramMap);
		return ResponseFormatterHelper.success(sign);

	}


	@RequestMapping(value = "/get-temporary-url", method = RequestMethod.GET)
	@ApiOperation(value = "获取临时地址")
	public BaseDtoResponse<String> getTemporaryUrlByOriginalUrl(@RequestParam(value = "originalUrl",required = true) String originalUrl){
		return comOssFacade.getTemporaryUrlByOriginalUrl(originalUrl);
	}

	@RequestMapping(value = "/get-temporary-url-bath", method = RequestMethod.GET)
	@ApiOperation(value = "批量获取临时地址")
	public BaseDtoResponse<List<String>> getBathTemporaryUrlByOriginalUrl(@RequestParam(value = "urls",required = true) List<String> originalUrls){
		return comOssFacade.getBathTemporaryUrlByOriginalUrl(originalUrls);
	}







	public  String generateSign( String signKey,  Map<String, String> params) {
		List<String> storedKeys = Arrays.stream(params.keySet()
														.toArray(new String[]{}))
										  .sorted(Comparator.naturalOrder())
										  .collect(Collectors.toList());
		final String sign = storedKeys.stream()
									.filter(key -> !Objects.equals(key, Constants.SIGN))
									.map(key -> String.join("", key, params.get(key)))
									.collect(Collectors.joining()).trim()
									.concat(signKey);
		return DigestUtils.md5DigestAsHex(sign.getBytes()).toUpperCase();
	}

	private Map<String, String> buildParamsMap(final RequestDTO dto) {
		Map<String, String> map = Maps.newHashMapWithExpectedSize(3);
		map.put(Constants.TIMESTAMP, dto.getTimestamp());
		map.put(Constants.PATH, dto.getPath());
		map.put(Constants.VERSION, "1.0.0");
		return map;
	}

}
