package com.ydl.auth.service.facade;


import com.alibaba.dubbo.config.annotation.Service;
import com.ydl.auth.inf.AppAuthFacade;
import com.ydl.auth.inf.ComOssFacade;
import com.ydl.auth.service.enums.YunYMEnum;
import com.ydl.auth.service.utils.OssUrlUtil;
import com.ydl.common.dto.BaseDtoResponse;
import com.ydl.common.helper.ResponseFormatterHelper;
import com.ydl.common.service.RedisCacheStorage;
import com.ydl.common.utils.Util;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;


/**
 * @program ydl-auth
 * @description: ComOssFacadeImpl
 * @author: wangjianfeng
 * @create: 2020/03/03 18:31
 */
@Service(version = "1.0.0",interfaceClass = ComOssFacade.class,timeout = 500000)
public class ComOssFacadeImpl implements ComOssFacade {


	private static Long expressedTime = 3600 * 1000l;

	@Resource
	private RedisCacheStorage redisCacheStorage;

	@Resource
	private OssUrlUtil ossUrlUtil;

	@Override
	public BaseDtoResponse<String> getTemporaryUrlByOriginalUrl(String originalUrl) {

		String resultUrl = "";

		String rKey = "oss_"+originalUrl;

		String rStr = redisCacheStorage.sget(rKey).toString();
		if(Util.isEmpty(rStr)||rStr.length()!=0){
			return ResponseFormatterHelper.success(rStr);
		}

		originalUrl =originalUrl.replace("http://","");
		originalUrl = originalUrl.replace("https://","");
		if(originalUrl.startsWith(YunYMEnum.QN_STATIC1.getValue())
		  ||originalUrl.startsWith(YunYMEnum.QN_VIDEEO.getValue())
		  ||originalUrl.startsWith(YunYMEnum.QN_STATIC2.getValue())
		  ||originalUrl.startsWith(YunYMEnum.QN_HAOSHI99.getValue())
		){

			String host = "";
			//七牛云逻辑
			if(originalUrl.startsWith(YunYMEnum.QN_STATIC1.getValue())){
				host = YunYMEnum.QN_STATIC1.getValue();
			}
			else if(originalUrl.startsWith(YunYMEnum.QN_VIDEEO.getValue())){
				host = YunYMEnum.QN_VIDEEO.getValue();
			}
			else if(originalUrl.startsWith(YunYMEnum.QN_STATIC2.getValue())){
				host = YunYMEnum.QN_STATIC2.getValue();
			}
			else if(originalUrl.startsWith(YunYMEnum.QN_HAOSHI99.getValue())){
				host = YunYMEnum.QN_HAOSHI99.getValue();
			}

			String key = originalUrl.replace(host,"");

			resultUrl = ossUrlUtil.getQnyTemporaryUrl(host,key,expressedTime);

		}
		else if(originalUrl.startsWith(YunYMEnum.AL_IMG.getValue())
		||originalUrl.startsWith(YunYMEnum.AL_FILE.getValue())
		||originalUrl.startsWith(YunYMEnum.AL_REDORD.getValue())){
			//阿里云逻辑

			String host = "";
			//七牛云逻辑
			if(originalUrl.startsWith(YunYMEnum.AL_IMG.getValue())){
				host = YunYMEnum.AL_IMG.getValue();
			}
			else if(originalUrl.startsWith(YunYMEnum.AL_FILE.getValue())){
				host = YunYMEnum.AL_FILE.getValue();
			}
			else if(originalUrl.startsWith(YunYMEnum.AL_REDORD.getValue())){
				host = YunYMEnum.AL_REDORD.getValue();
			}

			String key = originalUrl.replace(host,"");

			resultUrl = ossUrlUtil.getAliyTemporaryUrl(host,key,expressedTime);
		}
		else if(originalUrl.startsWith(YunYMEnum.YP_IMG.getValue())
		||originalUrl.startsWith(YunYMEnum.YP_IMG2.getValue())
		||originalUrl.startsWith(YunYMEnum.YP_M.getValue())){
			//又拍云逻辑

			String host = "";
			//七牛云逻辑
			if(originalUrl.startsWith(YunYMEnum.YP_IMG.getValue())){
				host = YunYMEnum.YP_IMG.getValue();
			}
			else if(originalUrl.startsWith(YunYMEnum.YP_IMG2.getValue())){
				host = YunYMEnum.YP_IMG2.getValue();
			}
			else if(originalUrl.startsWith(YunYMEnum.YP_M.getValue())){
				host = YunYMEnum.YP_M.getValue();
			}
			String key = originalUrl.replace(host,"");

			resultUrl = ossUrlUtil.getYpyTemporaryUrl(host,key,expressedTime);
		}


		redisCacheStorage.sset(rKey,resultUrl,expressedTime-10000);//设短一点防止交叉时间取不到


		return ResponseFormatterHelper.success(resultUrl);
	}

	@Override
	public BaseDtoResponse<List<String>> getBathTemporaryUrlByOriginalUrl(List<String> originalUrls) {

		List<String> resultList = new ArrayList<>();
		for (String url: originalUrls) {
			String result = getTemporaryUrlByOriginalUrl(url).getData();
			resultList.add(result);
		}

		return ResponseFormatterHelper.success(resultList);
	}



}
